====================================================
Cython headers for MurmurHash
====================================================

Cython .pxd files for some of the MurmurHash 2 and 3 hash functions, with a
slightly more Pythonic API.  The only access to these functions is via Cython ---
I don't see why they should be useful from pure Python.
